@@ -7,7 +7,7 @@ use Carp 'carp';
 use v5.10.1;
 
 our @CARP_NOT;
-our $VERSION = '0.17_1';
+our $VERSION = '0.19_1';
 
 our $DEFAULT_KEY_SIZE = 512;
 our $MAX_GEN_ROUNDS = 100;
@@ -35,13 +35,13 @@ use Exporter 'import';
 our @EXPORT_OK = qw(b64url_encode b64url_decode);
 
 # Primitive for Math::Prime::Util
-sub random_nbit_prime;
+sub random_nbit_prime ($);
 
 our $GENERATOR;
 
 # Load Math::Prime::Util and Math::Random::Secure
 BEGIN {
-  if (eval q{use Math::Prime::Util 0.21 'random_nbit_prime'; 1;}) {
+  if (eval q{use Math::Prime::Util 'random_nbit_prime'; 1;}) {
     our $GENERATOR = 1;
   };
 };
@@ -59,7 +59,7 @@ sub new {
   if (my $bl = blessed($_[0])) {
 
     # It's already a MagicKey object - fine!
-    return $_[0] if $bl eq __PACKAGE__;
+    return $_[0] if $bl->isa(__PACKAGE__);
   }
 
   # Do not support references
@@ -842,7 +842,8 @@ L<Math::Prime::Util::GMP> and L<Math::Random::ISAAC::XS>
 =head1 KNOWN BUGS AND LIMITATIONS
 
 The signing and verification is not guaranteed to be
-compatible with other implementations!
+compatible with other implementations, as the specification
+changed over time!
 
 
 =head1 SEE ALSO
@@ -860,7 +861,7 @@ L<https://github.com/sivy/Salmon>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2016, L<Nils Diewald|http://nils-diewald.de/>.
+Copyright (C) 2012-2017, L<Nils Diewald|http://nils-diewald.de/>.
 
 This program is free software, you can redistribute it
 and/or modify it under the terms of the Artistic License version 2.0.
